@@ -161,9 +161,15 @@ void App::onNewInstance(QStringList args)
   cmdParser_.parse(args);
 
   if (cmdParser_.isSet("toggle-manual-profile")) {
-    auto profileName = cmdParser_.value("toggle-manual-profile");
-    if (!profileName.isEmpty() && profileName.length() < 512)
-      session_->toggleManualProfile(profileName.toStdString());
+    auto profileName = cmdParser_.value("toggle-manual-profile").toStdString();
+    if (profileName.empty() || profileName.length() >= 512)
+      LOG(WARNING) << fmt::format("'{}' is not a valid manual profile name.",
+                                  profileName);
+    else if (!session_->toggleManualProfile(profileName))
+      LOG(WARNING) << fmt::format(
+          "Cannot toggle manual profile '{}': Missing profile or not a "
+          "manual profile.",
+          profileName);
   }
   else {
     auto show = true;
