@@ -64,7 +64,7 @@ parseDPMStates(std::vector<std::string> const &ppDpmLines)
                          std::regex::icase);
   std::vector<std::pair<unsigned int, units::frequency::megahertz_t>> states;
 
-  for (auto &line : ppDpmLines) {
+  for (auto const &line : ppDpmLines) {
     std::smatch result;
     if (!std::regex_search(line, result, regex))
       return {};
@@ -94,7 +94,7 @@ parseDPMCurrentStateIndex(std::vector<std::string> const &ppDpmLines)
   // '*' marks the current state
   std::regex const regex(R"(^(\d+)\s*:\s*\d+\s*Mhz\s*\*\s*$)", std::regex::icase);
 
-  for (auto &line : ppDpmLines) {
+  for (auto const &line : ppDpmLines) {
     std::smatch result;
     if (std::regex_search(line, result, regex)) {
       unsigned int index{0};
@@ -121,7 +121,7 @@ parsePowerProfileModeModes(std::vector<std::string> const &ppPowerProfileModeLin
   std::regex const regex(R"(^\s*(\d+)\s+([^\*\(\s:]+))");
   std::vector<std::pair<std::string, int>> modes;
 
-  for (auto &line : ppPowerProfileModeLines) {
+  for (auto const &line : ppPowerProfileModeLines) {
 
     std::smatch result;
     if (!std::regex_search(line, result, regex))
@@ -155,7 +155,7 @@ std::optional<int> parsePowerProfileModeCurrentModeIndex(
   //   1 3D_FULL_SCREEN*
   std::regex const regex(R"(^\s*(\d+)\s+(?:[^\*\(\s]+)\s*\*)");
 
-  for (auto &line : ppPowerProfileModeLines) {
+  for (auto const &line : ppPowerProfileModeLines) {
 
     std::smatch result;
     if (!std::regex_search(line, result, regex))
@@ -540,7 +540,7 @@ parseOverdriveClkControls(std::vector<std::string> const &ppOdClkVoltageLines)
   std::regex const regex(R"(^OD_(\wCLK):\s*$)", std::regex::icase);
   std::vector<std::string> controlNames;
 
-  for (auto &line : ppOdClkVoltageLines) {
+  for (auto const &line : ppOdClkVoltageLines) {
     std::smatch result;
     if (!std::regex_search(line, result, regex))
       continue;
@@ -585,7 +585,7 @@ std::optional<std::vector<unsigned int>> ppOdClkVoltageFreqRangeOutOfRangeStates
 
   std::vector<unsigned int> states;
   auto [min, max] = *range;
-  for (auto &[index, clk] : *clks) {
+  for (auto const &[index, clk] : *clks) {
     if (!(clk >= min && clk <= max))
       states.push_back(index);
   }
