@@ -3,14 +3,12 @@
 
 #pragma once
 
+#include "core/idatasource.h"
 #include "pmauto.h"
 #include <memory>
 #include <string>
 #include <string_view>
 
-template<typename...>
-class IDataSource;
-
 namespace AMD {
 
 class PMAutoR600 : public AMD::PMAuto
