@@ -5,7 +5,6 @@
 
 #include "../infoproviderregistry.h"
 #include "common/stringutils.h"
-#include "core/idatasource.h"
 #include "swinfokerneldatasource.h"
 #include <easylogging++.h>
 #include <string_view>
@@ -17,7 +16,7 @@ SWInfoKernel::SWInfoKernel(
 {
 }
 
-std::vector<std::pair<std::string, std::string>> SWInfoKernel::provideInfo()
+std::vector<std::pair<std::string, std::string>> SWInfoKernel::provideInfo() const
 {
   std::vector<std::pair<std::string, std::string>> info;
 
