@@ -465,17 +465,33 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
       REQUIRE(p1Volt == units::voltage::millivolt_t(900));
     }
 
-    SECTION("Returns nothing when there is no OD_VDDC_CURVE: in input")
+    SECTION("Returns nothing...")
     {
-      // clang-format off
+      SECTION("When there is no OD_VDDC_CURVE: in input")
+      {
+        // clang-format off
       std::vector<std::string> input{"OTHER:",
                                      "0: 700Mhz 800mV",
                                      "2: 800Mhz 900mV",
                                      "OD_RANGE:"};
-      // clang-format on
+        // clang-format on
 
-      auto empty = ::Utils::AMD::parseOverdriveVoltCurve(input);
-      REQUIRE_FALSE(empty.has_value());
+        auto empty = ::Utils::AMD::parseOverdriveVoltCurve(input);
+        REQUIRE_FALSE(empty.has_value());
+      }
+
+      SECTION("When the voltage curve points have missing coordinates")
+      {
+        // clang-format off
+      std::vector<std::string> input{"OD_VDDC_CURVE:",
+                                     "0: 800mV",
+                                     "1: 800Mhz",
+                                     "OD_RANGE:"};
+        // clang-format on
+
+        auto empty = ::Utils::AMD::parseOverdriveVoltCurve(input);
+        REQUIRE_FALSE(empty.has_value());
+      }
     }
   }
 
@@ -832,16 +848,33 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
   {
     SECTION("Returns true when overdrive has voltage curve control")
     {
-      std::vector<std::string> data{"OD_VDDC_CURVE:"};
+      // clang-format off
+      std::vector<std::string> data{"OD_VDDC_CURVE:",
+                                    "0: 700Mhz 800mV",};
+      // clang-format on
 
       REQUIRE(::Utils::AMD::hasOverdriveVoltCurveControl(data));
     }
 
-    SECTION("Returns false when overdrive has no voltage curve control")
+    SECTION("Returns false...")
     {
-      std::vector<std::string> noClkControlData{"OTHER_DATA"};
+      SECTION("When overdrive has no voltage curve control")
+      {
+        std::vector<std::string> data{"OTHER_DATA"};
 
-      REQUIRE_FALSE(::Utils::AMD::hasOverdriveVoltCurveControl(noClkControlData));
+        REQUIRE_FALSE(::Utils::AMD::hasOverdriveVoltCurveControl(data));
+      }
+
+      SECTION("When overdrive has no valid voltage curve points")
+      {
+        // clang-format off
+        std::vector<std::string> data{"OD_VDDC_CURVE:",
+                                      "0: 800mV",
+                                      "OD_RANGE:"};
+        // clang-format on
+
+        REQUIRE_FALSE(::Utils::AMD::hasOverdriveVoltCurveControl(data));
+      }
     }
   }
 
@@ -856,10 +889,9 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
 
     SECTION("Returns false when overdrive has no voltage curve control")
     {
-      std::vector<std::string> noClkControlData{"OTHER_DATA"};
+      std::vector<std::string> data{"OTHER_DATA"};
 
-      REQUIRE_FALSE(
-          ::Utils::AMD::hasOverdriveVoltOffsetControl(noClkControlData));
+      REQUIRE_FALSE(::Utils::AMD::hasOverdriveVoltOffsetControl(data));
     }
   }
 }
